@@ -11,7 +11,7 @@
 # Modules and declarations
 ##############################################################################
 
-package App::DocKnot::Spin 7.00;
+package App::DocKnot::Spin v8.0.0;
 
 use 5.024;
 use autodie;
@@ -23,6 +23,7 @@ use App::DocKnot::Spin::Sitemap;
 use App::DocKnot::Spin::Thread;
 use App::DocKnot::Spin::Versions;
 use App::DocKnot::Util qw(is_newer print_checked print_fh);
+use Encode qw(decode);
 use Git::Repository ();
 use IPC::System::Simple qw(capture);
 use Path::Iterator::Rule ();
@@ -82,8 +83,9 @@ sub _footer {
             $modified = sprintf('%d-%02d-%02d', $1, $2, $3);
         }
     } elsif ($self->{repository} && $in_tree) {
-        $modified
-          = $self->{repository}->run('log', '-1', '--format=%ct', "$source");
+        $modified = $self->{repository}->run(
+            'log', '-1', '--format=%ct', "$source",
+        );
         if ($modified) {
             $modified = strftime('%Y-%m-%d', gmtime($modified));
         }
@@ -186,6 +188,7 @@ sub _cl2xhtml {
     my ($self, $source, $output, $options, $style) = @_;
     $style ||= $self->{style_url} . 'changelog.css';
     my @page = capture("cl2xhtml $options -s $style $source");
+    @page = map { decode('utf-8', $_) } @page;
     my $footer = sub {
         my ($blurb, $id) = @_;
         if ($blurb) {
@@ -216,6 +219,7 @@ sub _cvs2xhtml {
 
     # Run the converter and write the output.
     my @page = capture("(cd $dir && cvs log $name) | cvs2xhtml $options");
+    @page = map { decode('utf-8', $_) } @page;
     my $footer = sub {
         my ($blurb, $id, $file) = @_;
         if ($blurb) {
@@ -234,6 +238,7 @@ sub _faq2html {
     my ($self, $source, $output, $options, $style) = @_;
     $style ||= $self->{style_url} . 'faq.css';
     my @page = capture("faq2html $options -s $style $source");
+    @page = map { decode('utf-8', $_) } @page;
     my $footer = sub {
         my ($blurb, $id, $file) = @_;
         if ($blurb) {
@@ -270,6 +275,7 @@ sub _pod2html {
     my $data;
     $podthread->output_string(\$data);
     $podthread->parse_file("$source");
+    $data = decode('utf-8', $data);
 
     # Spin that thread into HTML.
     my $page = $self->{thread}->spin_thread($data);
@@ -482,13 +488,11 @@ sub new {
     }
 
     # Create and return the object.
-    #<<<
     my $self = {
         delete    => $args_ref->{delete},
         excludes  => [@excludes],
         style_url => $style_url,
     };
-    #>>>
     bless($self, $class);
     return $self;
 }
@@ -548,7 +552,6 @@ sub spin {
     }
 
     # Create a new thread converter object.
-    #<<<
     $self->{thread} = App::DocKnot::Spin::Thread->new(
         {
             output      => $output,
@@ -558,10 +561,8 @@ sub spin {
             versions    => $self->{versions},
         },
     );
-    #>>>
 
     # Create the processor for pointers.
-    #<<<
     $self->{pointer} = App::DocKnot::Spin::Pointer->new(
         {
             output      => "$output",
@@ -570,19 +571,19 @@ sub spin {
             thread      => $self->{thread},
         },
     );
-    #>>>
 
     # Process the input tree.
+    my %options = (follow_symlinks => 0, report_symlinks => 1);
     $rule = Path::Iterator::Rule->new();
     $rule = $rule->skip($rule->new()->name($self->{excludes}->@*));
-    $iter = $rule->iter("$input", { follow_symlinks => 0 });
+    $iter = $rule->iter("$input", \%options);
     while (defined(my $file = $iter->())) {
         $self->_process_file(path($file));
     }
 
     # Remove stray files from the output tree.
     if ($self->{delete}) {
-        my %options = (depthfirst => 1, follow_symlinks => 0);
+        $options{depthfirst} = 1;
         $iter = $rule->iter("$output", \%options);
         while (defined(my $file = $iter->())) {
             $self->_delete_files(path($file));
@@ -600,7 +601,7 @@ __END__
 
 =for stopwords
 Allbery DocKnot MERCHANTABILITY NONINFRINGEMENT sublicense cvs2xhtml faq2html
-cl2xhtml spin-rss
+cl2xhtml RSS
 
 =head1 NAME
 
@@ -616,10 +617,11 @@ App::DocKnot::Spin - Static site builder supporting thread macro language
 =head1 REQUIREMENTS
 
 Perl 5.24 or later and the modules Git::Repository, Image::Size,
-List::SomeUtils, Path::Iterator::Rule, Path::Tiny, Pod::Thread, Template (part
-of Template Toolkit), and YAML::XS, all of which are available from CPAN.
-Also expects to find B<faq2html>, B<cvs2xhtml>, and B<cl2xhtml> on the user's
-PATH to convert certain types of files.
+List::SomeUtils, Path::Iterator::Rule, Path::Tiny, Pod::Thread,
+Sort::Versions, Template (part of Template Toolkit), and YAML::XS, all of
+which are available from CPAN.  Also expects to find B<faq2html>,
+B<cvs2xhtml>, and B<cl2xhtml> on the user's PATH to convert certain types of
+files.
 
 =head1 DESCRIPTION
 
@@ -644,6 +646,11 @@ Most files in the input tree will normally be thread files ending in C<.th>.
 These are processed into HTML using L<App::DocKnot::Spin::Thread>.  See that
 module's documentation for the details of the thread macro language.
 
+Files that end in C<.spin> are pointers to external files that should be
+converted to HTML and then written to the output tree.  These pointers are
+interpreted by L<App::DocKnot::Spin::Pointer>.  See that module's
+documentation for their format and effects.
+
 Files that end in various other extensions are taken to be instructions to run
 an external converter on a file.  The first line of such a pointer file should
 be the path to the source file, the second line any arguments to the
@@ -670,11 +677,10 @@ parsed with L<App::DocKnot::Spin::Versions> and used to determine when to
 regenerate certain pages and for the C<\release> and C<\version> thread
 commands.  See that module's documentation for the format of this file.
 
-If there is a file named F<.rss> in any directory of the input tree,
-B<spin-rss> will be run on that file, passing the B<-b> option to point to the
-directory about to be processed.  This is done before processing the files in
-that directory, so B<spin-rss> can create or update files that will then be
-processed as normal.
+If there is a file named F<.rss> in any directory of the input tree, it will
+be processed with L<App::DocKnot::Spin::RSS> to generate RSS and possibly
+other files.  This is done before processing the files in that directory so
+that the generated files will then be processed as normal.
 
 If there is a directory named F<.git> at the top of the input tree,
 App::DocKnot::Spin will assume that the input tree is a Git repository and
@@ -732,7 +738,7 @@ Russ Allbery <rra@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1999-2011, 2013, 2021-2022 Russ Allbery <rra@cpan.org>
+Copyright 1999-2011, 2013, 2021-2023 Russ Allbery <rra@cpan.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -755,7 +761,8 @@ SOFTWARE.
 =head1 SEE ALSO
 
 L<cl2xhtml(1)>, L<cvs2xhtml(1)>, L<docknot(1)>, L<faq2html(1)>,
-L<spin-rss(1)>, L<App::DocKnot::Spin::Sitemap>, L<App::DocKnot::Spin::Thread>,
+L<App::DocKnot::Spin::Pointer>, L<App::DocKnot::Spin::RSS>,
+L<App::DocKnot::Spin::Sitemap>, L<App::DocKnot::Spin::Thread>,
 L<App::DocKnot::Spin::Versions>, L<Pod::Thread>
 
 This module is part of the App-DocKnot distribution.  The current version of
